@@ -18,21 +18,16 @@ from netbox_storage.models import Partition, PhysicalVolume, VolumeGroup, Drive
 
 class PhysicalVolumeForm(NetBoxModelForm):
     """Form for creating a new PhysicalVolume object."""
-    drive_id = DynamicModelChoiceField(
+    drive = DynamicModelChoiceField(
         queryset=Drive.objects.all(),
         label="Drive",
-        initial_params={
-            'partitions': '$partition'
-        },
         help_text="The Drive e.g. Hard Drive 1",
     )
     partition = DynamicModelChoiceField(
-        queryset=Partition.objects.filter(
-    # ct = ClusterType.objects.filter(name="Storage").values_list('id', flat=True)[0]
-        ),
+        queryset=Partition.objects.all(),
         label="Partition",
         query_params={
-            'drive_id': '$drive_id'
+            'drive_id': '$drive'
         },
         help_text="The Partition of the Drive e.g. /dev/sdc1",
     )
@@ -59,7 +54,7 @@ class PhysicalVolumeForm(NetBoxModelForm):
         (
             "Storage Configuration",
             (
-                "drive_id",
+                "drive",
                 "partition",
             ),
         ),
