@@ -280,12 +280,12 @@ class LogicalVolume(NetBoxModel):
         "description",
     ]
 
-    prerequisite_models = (
-        'netbox_storage.Filesystem',
-        'netbox_storage.VolumeGroup',
-        'netbox_storage.PhysicalVolume',
-        'netbox_storage.Drive',
-    )
+    #prerequisite_models = (
+    #    'netbox_storage.Filesystem',
+    #    'netbox_storage.VolumeGroup',
+    #    'netbox_storage.PhysicalVolume',
+    #    'netbox_storage.Drive',
+    #)
 
     def get_absolute_url(self):
         return reverse("plugins:netbox_storage:logicalvolume", kwargs={"pk": self.pk})
@@ -328,11 +328,11 @@ class LinuxVolume(NetBoxModel):
         "description",
     ]
 
-    prerequisite_models = (
-        'netbox_storage.Filesystem',
-        'netbox_storage.Drive',
-        'netbox_storage.Partition',
-    )
+    #prerequisite_models = (
+    #    'netbox_storage.Filesystem',
+    #    'netbox_storage.Drive',
+    #    'netbox_storage.Partition',
+    #)
 
     def get_absolute_url(self):
         return reverse("plugins:netbox_storage:linuxvolume", kwargs={"pk": self.pk})
