@@ -135,6 +135,28 @@ logicalvolume_menu_item = PluginMenuItem(
     ),
 )
 
+linuxvolume_menu_item = PluginMenuItem(
+    link="plugins:netbox_storage:linuxvolume_list",
+    link_text="Linux Volume",
+    permissions=["netbox_storage.disk_view"],
+    buttons=(
+        PluginMenuButton(
+            "plugins:netbox_storage:linuxvolume_add",
+            "Add",
+            "mdi mdi-plus-thick",
+            ButtonColorChoices.GREEN,
+            permissions=["netbox_storage.add_disk"],
+        ),
+        PluginMenuButton(
+            "plugins:netbox_storage:linuxvolume_import",
+            "Import",
+            "mdi mdi-upload",
+            ButtonColorChoices.CYAN,
+            permissions=["netbox_storage.add_disk"],
+        ),
+    ),
+)
+
 menu = PluginMenu(
     label="NetBox Storage",
     groups=(
@@ -155,9 +177,7 @@ menu = PluginMenu(
         (
             "Linux Volume Configuration",
             (
-                logicalvolume_menu_item,
-                volumegroup_menu_item,
-                physicalvolume_menu_item,
+                linuxvolume_menu_item,
             ),
         ),
         (
