@@ -60,7 +60,8 @@ from netbox_storage.views import (
     LinuxVolumeBulkEditView,
     LinuxVolumeBulkDeleteView,
     LinuxVolumeView,
-    LinuxVolumeDeleteView, VolumeGroupPhysicalVolumeListView, VolumeGroupLogicalVolumeListView,
+    LinuxVolumeDeleteView, VolumeGroupPhysicalVolumeListView, VolumeGroupLogicalVolumeListView, LVMAddSimpleView,
+    LVAddSimpleView,
 )
 
 app_name = "netbox_storage"
@@ -190,4 +191,9 @@ urlpatterns = [
         name="linuxvolume_changelog",
         kwargs={"model": LinuxVolume},
     ),
+    #
+    # Simple Configuration
+    #
+    path("lvm-simple/add/", LVMAddSimpleView.as_view(), name="lvm_simple_add"),
+    path("lv-simple/add/", LVAddSimpleView.as_view(), name="lv_simple_add"),
 ]
